import { Component, OnInit, Inject, ViewChild } from '@angular/core';
import { data } from './data';
import {
  Router,
  Event,
  NavigationStart, RoutesRecognized, RouteConfigLoadStart,
  RouteConfigLoadEnd, NavigationEnd, NavigationCancel, NavigationError
} from '@angular/router';
// import { Internationalization } from '@syncfusion/ej2-base';
import { DatePicker } from '@syncfusion/ej2-calendars';
import { ClickEventArgs } from '@syncfusion/ej2-navigations';
import { GridComponent, ContextMenuItemModel, IEditCell } from '@syncfusion/ej2-ng-grids';


@Component({
  selector: 'app-container',
  template: `<ejs-grid #grid [dataSource]='data' id="gridcomp"
  allowPaging='true' [editSettings]='editSettings' [toolbar]='toolbarItems' height='220px'>
        <e-columns>
            <e-column field='OrderID' headerText='Order ID' width='120' isPrimaryKey='true'></e-column>
            <e-column field='CustomerID' headerText='Customer Name' width='120'></e-column>
             <e-column field='interval' headerText='interval' width='220'></e-column>
            <e-column field='Freight' headerText='Freight' width='120' type='number' allowEditing='false'
             format='C2' editType='numericedit'></e-column>
            <e-column field='ShipCity' headerText='Ship City' width='150'></e-column>
        </e-columns>
    </ejs-grid>`
})
export class AppComponent implements OnInit {

  public data: Object[];
  public editSettings: Object;
  public pageSettings: Object;
  public toolbarItems: String[];
  public div: HTMLElement;
  public elem1: HTMLElement;
  public datePickerObj1: DatePicker;
  public elem2: HTMLElement;
  public datePickerObj2: DatePicker;
  // public intl: Internationalization = new Internationalization();
  @ViewChild('grid')
  public grid: GridComponent;

  private datepickerTemplate: IEditCell = {
    create: () => {
      this.div = document.createElement('div');
      this.div.style.width = '50%';
      this.elem1 = document.createElement('input');
      this.div.appendChild(this.elem1);
      this.elem2 = document.createElement('input');
      this.div.appendChild(this.elem2);
      return this.div;
    },
    read: () => {
      console.log("read")
      // const string1: string = this.intl.formatDate(this.datePickerObj1.value,
      //   { format: 'yyyy-MM-dd' });
      // const string2: string = this.intl.formatDate(this.datePickerObj2.value,
      //   { format: 'yyyy-MM-dd' });
      // const interval = string1 + '/' + string2;
      // (this.grid.columns[2] as any).editTemplate = undefined;
      // return interval;
    },
    
    destroy: () => {
      this.datePickerObj1.destroy();
      this.datePickerObj2.destroy();
    },
    write: (args: { rowData: Object, column: any }) => {
      args.column.editTemplate = args.column.edit;
      const dates: string = args.rowData[args.column.field].split('/');

      this.datePickerObj1 = new DatePicker({
        value: new Date(dates[0]),
        floatLabelType: 'Never'
      });
      this.datePickerObj1.appendTo(this.elem1);

      this.datePickerObj2 = new DatePicker({
        value: new Date(dates[1]),
        floatLabelType: 'Never'
      });
      this.datePickerObj2.appendTo(this.elem2);
    }
  };

  ngOnInit(): void {
    this.data = data;
    this.pageSettings = { pageSize: 2 };
    this.editSettings = { allowEditing: true, allowAdding: true, allowDeleting: true, mode: 'Batch' };
    this.toolbarItems = ['Add', 'Edit', 'Delete', 'Cancel', 'Update'];

    this.grid.cellEdit.subscribe(i => this.renderCellTemplateByDataType(i))
    this.grid.cellSave.subscribe(i => console.log(i))

  }

  /**
 * Renders data by given datatype from database
 * @param args 
 */
  private renderCellTemplateByDataType(args) {
    args.columnObject.edit = this.datepickerTemplate;
  }
}
