import { Component, OnInit, Inject, ViewChild } from '@angular/core';
import { data } from './data';
import {
    Router,
    Event,
    NavigationStart, RoutesRecognized, RouteConfigLoadStart,
    RouteConfigLoadEnd, NavigationEnd, NavigationCancel, NavigationError
} from '@angular/router';

import { ClickEventArgs } from '@syncfusion/ej2-navigations';
// import { GridComponent } from '@syncfusion/ej2-angular-grids';


@Component({
    selector: 'app-container',
    template: `<ejs-grid id="grid" #grid [dataSource]='data' [allowPaging]='true' [pageSettings]="pageSettings" 
                [editSettings]='editOptions' [toolbar]='toolbarItems'
                (actionBegin)='actionBegin($event)' (cellSaved)='cellSaved($event)' (cellSave)='cellSave($event)' 
                (actionComplete)='actionComplete($event)'> 
              <e-columns>
                <e-column field='OrderID' headerText='Id' isPrimaryKey='true' [visible]='false'></e-column>
                <e-column field='OrderDate' headerText='OrderDate' editType='datepickeredit'
                 [format]='dateformatoptions' textAlign='Right' width='112'></e-column>
                <e-column field='Freight' type='number' headerText='Freight' editType="numericedit"
                 format='N2' textAlign='Right' width='112'></e-column>
              </e-columns>
              <e-aggregates>
                <e-aggregate>
                    <e-columns>
                        <e-column field="Freight" type="sum">
                            <ng-template #footerTemplate let-data>Total: {{data.sum}}</ng-template>
                        </e-column>
                    </e-columns>
                </e-aggregate>
              </e-aggregates>`
})
export class FirstComponent implements OnInit {

    public data: Object[];
    public editOptions: Object;
    public pageSettings: Object;
    public toolbarItems: String[];
    @ViewChild('grid')
    public grid: any;

    ngOnInit(): void {
        this.data = data;
        this.pageSettings = { pageSize: 10 };
        this.editOptions = { allowEditing: true, allowAdding: true, allowDeleting: true, mode: 'Batch' };
        this.toolbarItems = ['Add', 'Edit', 'Delete', 'Cancel', 'Update'];
    }
    actionBegin(e) {
        console.log('Begin');
    }
    cellSaved(e) {
        console.log('saved');
    }
    cellSave(e) {
        console.log('save');
    }
    actionComplete(e) {
        console.log('Completed');
    }
}
